LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
 
ENTITY SimExampleTestBench IS
-- always leave this empty!
END SimExampleTestBench;
 
ARCHITECTURE behavior OF SimExampleTestBench IS 
 
	 -- this component is the circuit we designed!
	 -- iSIM will silently fail to simulate the circuit
	 -- if this component name doesn't match the entity name
	 -- of your design!
    COMPONENT SimExampleCircuit
		PORT( i0 : IN  std_logic; i1 : IN  std_logic;  q : OUT  std_logic  );
    END COMPONENT;
  
	--iSim will display these signals on-screen when you run it! 
	-----------------------------------------------------------
   --Inputs
	--I like to initialize them to strong drive, you can set them to '0' if you prefer
   signal si0 : std_logic := 'X';
   signal si1 : std_logic := 'X';

 	--Outputs
   signal sq : std_logic;

	BEGIN
	 
		-- make an instance of the Unit Under Test (UUT)
		-- the unit under test is the circuit we designed!
		
		-- we're wiring our circuit to the signals we just made in the simulator's
		-- architecture
		uut: SimExampleCircuit PORT MAP ( i0 => si0, i1 => si1,  q => sq );

		sim_main: process
		begin		
			-- hold 'X', 'X' ("strong drive") state for 100 ns.
			wait for 100 ns;
			
			-- now let's go through the truth table for this design,
			-- let's set every combination of inputs!
			
			-- set to '0', '0' and wait for 100 ns so we can see how it effects the output
			si0 <= '0';
			si1 <= '0';
			wait for 100 ns;
			
			-- set to '0', '1' and wait for 100 ns so we can see how it effects the output
			si0 <= '0';
			si1 <= '1';
			wait for 100 ns;
			
			-- set to '1', '0' and wait for 100 ns so we can see how it effects the output
			si0 <= '1';
			si1 <= '0';	
			wait for 100 ns;
			
			-- set to '1', '1' and wait for 100 ns so we can see how it effects the output
			si0 <= '1';
			si1 <= '1';	
			wait for 100 ns;
			
			-- repeats endlessly! 
			wait;
		end process sim_main;

END;

-- note: To run iSim for a longer period of time, type "run 10000 ns" or however long you
-- want to run it for in the console at the bottom!

-- note: right click on the waveform and click to "to full view" to see the full waveform.

-- note: to run a TIMING simulation, change the dropdown box under the "implementation"/"simulation"
-- selector to "post-fit", and run the simulation again.